"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PolygonDidResolver = void 0;
const polygon_did_resolver_1 = require("@ayanworks/polygon-did-resolver");
const core_1 = require("@credo-ts/core");
const did_resolver_1 = require("did-resolver");
const didPolygonUtil_1 = require("./didPolygonUtil");
class PolygonDidResolver {
    constructor() {
        this.allowsCaching = true;
        this.supportedMethods = ['polygon'];
        this.resolver = new did_resolver_1.Resolver((0, polygon_did_resolver_1.getResolver)());
    }
    async resolve(agentContext, did) {
        const didDocumentMetadata = {};
        if (!(0, didPolygonUtil_1.isValidPolygonDid)(did)) {
            throw new Error('Invalid DID');
        }
        try {
            const { didDocument, didDocumentMetadata, didResolutionMetadata } = await this.resolver.resolve(did);
            return {
                didDocument: core_1.JsonTransformer.fromJSON(didDocument, core_1.DidDocument),
                didDocumentMetadata,
                didResolutionMetadata,
            };
        }
        catch (error) {
            return {
                didDocument: null,
                didDocumentMetadata,
                didResolutionMetadata: {
                    error: 'notFound',
                    message: `resolver_error: Unable to resolve did '${did}': ${error}`,
                },
            };
        }
    }
}
exports.PolygonDidResolver = PolygonDidResolver;
//# sourceMappingURL=PolygonDidResolver.js.map